Index: trunk/kernel/mm/mapper.h
===================================================================
--- trunk/kernel/mm/mapper.h	(revision 628)
+++ trunk/kernel/mm/mapper.h	(revision 635)
@@ -64,5 +64,5 @@
  * TODO (1) the mapper being only used to implement the VFS cache(s), the mapper.c
  *          and mapper.h file should be trandfered to the fs directory.
- * TODO (2) the "type" field is probably unused... 
+ * TODO (2) the "type" field in mapper descriptor is redundant and probably unused. 
  ******************************************************************************************/
 
@@ -106,20 +106,32 @@
 
 /*******************************************************************************************
  * This function load from device a missing page identified by the <page_id> argument
  * into the mapper identified by the <mapper> local pointer.
  * It allocates a physical page from the local cluster, initialise by accessing device,
  * and register the page in the mapper radix tree.
  * It must be executed by a thread running in the cluster containing the mapper.
  * WARNING : the calling function mapper_remote_get_page() is supposed to take and release
  * the lock protecting the mapper in WRITE_MODE.
  *******************************************************************************************
- * @ mapper	 : [in]  target mapper.
- * @ page_id : [in]  missing page index in file.
- * @ page_xp : [out] buffer for extended pointer on missing page descriptor.
- * @ return 0 if success / return -1 if a dirty page cannot be updated on device.
- ******************************************************************************************/
-error_t mapper_handle_miss( mapper_t * mapper,
-                            uint32_t   page_id,
-                            xptr_t   * page_xp );
+ * @ mapper_xp	 : [in]  extended pointer on remote mapper.
+ * @ page_id     : [in]  missing page index in file.
+ * @ page_xp     : [out] buffer for extended pointer on missing page descriptor.
+ * @ return 0 if success / return -1 if IOC cannot be accessed.
+ ******************************************************************************************/
+error_t mapper_remote_handle_miss( xptr_t     mapper_xp,
+                                   uint32_t   page_id,
+                                   xptr_t   * page_xp );
+
+/*******************************************************************************************
+ * This function removes a physical page from a - possibly remote - mapper,
+ * and releases the page to the remote PPM. 
+ * It can be executed by any thread running in any cluster. 
+ * It takes the mapper lock in WRITE_MODE to update the mapper.
+ *******************************************************************************************
+ * @ mapper	: extended pointer on the remote mapper.
+ * @ page	: local pointer on the page in remote mapper.
+ ******************************************************************************************/
+void mapper_remote_release_page( xptr_t          mapper_xp,
+                                 struct page_s * page );
 
 /*******************************************************************************************
@@ -170,16 +182,4 @@
 
 /*******************************************************************************************
- * This function removes a physical page from the mapper, and releases
- * the page to the local PPM. It is called by the mapper_destroy() function.
- * It must be executed by a thread running in the cluster containing the mapper.
- * It takes the mapper lock in WRITE_MODE to update the mapper.
- *******************************************************************************************
- * @ mapper	: local pointer on the mapper.
- * @ page	: pointer on page to remove.
- ******************************************************************************************/
-void mapper_release_page( mapper_t      * mapper,
-                          struct page_s * page );
-
-/*******************************************************************************************
  * This function returns an extended pointer on a page descriptor.
  * The - possibly remote - mapper is identified by the <mapper_xp> argument.
@@ -237,5 +237,5 @@
 /*******************************************************************************************
  * This function scan all pages present in the mapper identified by the <mapper> argument,
- * and synchronize all pages maked as dirty" on disk. 
+ * and synchronize all pages marked as "dirty" on disk. 
  * These pages are unmarked and removed from the local PPM dirty_list. 
  * This function must be called by a local thread running in same cluster as the mapper.
@@ -106,20 +106,32 @@
 
 /*******************************************************************************************
- * This function load from device a missing page identified by the <page_id> argument
- * into the mapper identified by the <mapper> local pointer.
- * It allocates a physical page from the local cluster, initialise by accessing device,
- * and register the page in the mapper radix tree.
- * It must be executed by a thread running in the cluster containing the mapper.
+ * This function load from the IOC device a missing page identified by the <page_id> 
+ * argument into a - possibly remote - mapper identified by the <mapper_xp> argument.
+ * It can be executed by a thread running in any cluster.
+ * It allocates a physical page from the remote cluster PPM, initialises it by accessing
+ * the IOC device, and registers the page in the remote mapper radix tree.
  * WARNING : the calling function mapper_remote_get_page() is supposed to take and release
  * the lock protecting the mapper in WRITE_MODE.
